==> huaweicloudsdkdli-3.1.82-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/update_queue_property_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateQueuePropertyRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'properties': 'UpdateQueuePropertyRequestBodyProperties'
    }

    attribute_map = {
        'properties': 'properties'
    }

    def __init__(self, properties=None):
        """UpdateQueuePropertyRequestBody

        The model defined in huaweicloud sdk

        :param properties: 
        :type properties: :class:`huaweicloudsdkdli.v1.UpdateQueuePropertyRequestBodyProperties`
        """
        
        

        self._properties = None
        self.discriminator = None

        if properties is not None:
            self.properties = properties

    @property
    def properties(self):
        """Gets the properties of this UpdateQueuePropertyRequestBody.

        :return: The properties of this UpdateQueuePropertyRequestBody.
        :rtype: :class:`huaweicloudsdkdli.v1.UpdateQueuePropertyRequestBodyProperties`
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this UpdateQueuePropertyRequestBody.

        :param properties: The properties of this UpdateQueuePropertyRequestBody.
        :type properties: :class:`huaweicloudsdkdli.v1.UpdateQueuePropertyRequestBodyProperties`
        """
        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateQueuePropertyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.93-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/update_queue_property_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateQueuePropertyRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'properties': 'AdvancedQueueProperty'
    }

    attribute_map = {
        'properties': 'properties'
    }

    def __init__(self, properties=None):
        """UpdateQueuePropertyRequestBody

        The model defined in huaweicloud sdk

        :param properties: 
        :type properties: :class:`huaweicloudsdkdli.v1.AdvancedQueueProperty`
        """
        
        

        self._properties = None
        self.discriminator = None

        if properties is not None:
            self.properties = properties

    @property
    def properties(self):
        """Gets the properties of this UpdateQueuePropertyRequestBody.

        :return: The properties of this UpdateQueuePropertyRequestBody.
        :rtype: :class:`huaweicloudsdkdli.v1.AdvancedQueueProperty`
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this UpdateQueuePropertyRequestBody.

        :param properties: The properties of this UpdateQueuePropertyRequestBody.
        :type properties: :class:`huaweicloudsdkdli.v1.AdvancedQueueProperty`
        """
        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateQueuePropertyRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
